pygeodesy.rhumb.ekx.RhumbLine

Package pygeodesy :: Package rhumb :: Module ekx :: Class RhumbLine |
[frames] | no frames]

# Class RhumbLine

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
        karney._CapsBase --+
                           |
         bases.RhumbLineBase --+
                               |
                              RhumbLine

Compute one or several points on a single rhumb line.

Class `RhumbLine` facilitates the determination of points on a single rhumb line. The starting point (`lat1`, `lon1`) and the azimuth `azi12` are specified once.

Instance Methods
__init__(self, rhumb, lat1=0, lon1=0, azi12=None, **caps_name) New `RhumbLine`. |
Inherited from `bases.RhumbLineBase`: `ArcPosition`, `Intersecant2`, `Intersection`, `Inverse`, `NearestOn`, `PlumbTo`, `Position`, `__del__`, `degrees2m`, `distance2`, `intersection2`, `m2degrees`, `nearestOn4`, `toStr` Inherited from `karney._CapsBase`: `caps_` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others`, `toRepr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables
Inherited from `karney._CapsBase`: `ALL`, `AREA`, `AZIMUTH`, `DISTANCE`, `DISTANCE_IN`, `EMPTY`, `GEODESICSCALE`, `LATITUDE`, `LINE_CAPS`, `LINE_OFF`, `LONGITUDE`, `LONG_UNROLL`, `NONFINITONAN`, `REDUCEDLENGTH`, `STANDARD`, `STANDARD_LINE`

Properties
| RAorder Get this rhumb line's Rhumb Area order (`int`, 4, 5, 6, 7 or 8).
Inherited from `bases.RhumbLineBase`: `TMorder`, `azi12`, `azi12_sincos2`, `datum`, `ellipsoid`, `exact`, `isLoxodrome`, `lat1`, `latlon1`, `lon1`, `rhumb`, `xTM` Inherited from `karney._CapsBase`: `caps`, `debug` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, rhumb, lat1=0, lon1=0, azi12=None, **caps_name) (Constructor) |
New `RhumbLine`. Arguments: `rhumb` - The rhumb reference (Rhumb). `lat1` - Latitude of the start point (`degrees90`). `lon1` - Longitude of the start point (`degrees180`). `azi12` - Azimuth of this rhumb line (compass `degrees`). `caps_name` - Optional keyword arguments `name=NN` and `caps=0`, a bit-or'ed combination of Caps values specifying the required capabilities. Include `Caps.LINE_OFF` if updates to the `rhumb` should not be reflected in this rhumb line. Overrides: object.__init__

Property Details

### RAorder Get this rhumb line's Rhumb Area order (`int`, 4, 5, 6, 7 or 8). Get method: RAorder(self) - Get this rhumb line's Rhumb Area order (`int`, 4, 5, 6, 7 or 8). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.